# VevoLab_Data_Extraction_Helper

## VevoLab Data Extraction Helper
tool to help with conversion of machine output from the VevoLab ultrasound software into an easier to use format for subsequent analysis. Additional feature (not fully implemented) include exploratory statistics and graphing.

written by Christopher Ward (C) 2021, christow@bcm.edu, ward.chris.s@gmail.com


## Setting things up

### PC versions (Precompiled)
* Extract the zipped folder into a convenient location on your computer
* In the root level of the unzipped folder, run the program Click on the "main.exe" executable (or make a shortcut pointing to this file)
* Use the program

### Running from source code
* Create a python environment
* install dependencies (requirements.txt)
* clone the repository
* launch the program using `python main.py`

### Installing from PyPI
* Create a python environment
* install via pip `pip install vdeh`
* launch the program using `python -m vdeh.main`


## Running the Program
* You may run the program as a gui operated tool
    * Select the VevoLab Reports containing the data for extraction
    * Select the output location
    * Run the Extraction/Analysis


## Reporting Bugs
to report any bugs or request new features, email Christopher Ward (christow@bcm.edu)


## manual available at
https://realchrisward.github.io/VevoLab_Data_Extraction_Helper/index.html
